// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: protobuf-c/protobuf-c.proto

#include "protobuf-c/protobuf-c.pb.h"

#include <algorithm>
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/extension_set.h"
#include "google/protobuf/wire_format_lite.h"
#include "google/protobuf/descriptor.h"
#include "google/protobuf/generated_message_reflection.h"
#include "google/protobuf/reflection_ops.h"
#include "google/protobuf/wire_format.h"
#include "google/protobuf/generated_message_tctable_impl.h"
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"
PROTOBUF_PRAGMA_INIT_SEG
namespace _pb = ::google::protobuf;
namespace _pbi = ::google::protobuf::internal;
namespace _fl = ::google::protobuf::internal::field_layout;

inline constexpr ProtobufCMessageOptions::Impl_::Impl_(
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        base_field_name_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        gen_pack_helpers_{false},
        gen_init_helpers_{true} {}

template <typename>
PROTOBUF_CONSTEXPR ProtobufCMessageOptions::ProtobufCMessageOptions(::_pbi::ConstantInitialized)
    : _impl_(::_pbi::ConstantInitialized()) {}
struct ProtobufCMessageOptionsDefaultTypeInternal {
  PROTOBUF_CONSTEXPR ProtobufCMessageOptionsDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~ProtobufCMessageOptionsDefaultTypeInternal() {}
  union {
    ProtobufCMessageOptions _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 ProtobufCMessageOptionsDefaultTypeInternal _ProtobufCMessageOptions_default_instance_;

inline constexpr ProtobufCFileOptions::Impl_::Impl_(
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        c_package_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        no_generate_{false},
        const_strings_{false},
        use_oneof_field_name_{false},
        gen_pack_helpers_{true},
        gen_init_helpers_{true} {}

template <typename>
PROTOBUF_CONSTEXPR ProtobufCFileOptions::ProtobufCFileOptions(::_pbi::ConstantInitialized)
    : _impl_(::_pbi::ConstantInitialized()) {}
struct ProtobufCFileOptionsDefaultTypeInternal {
  PROTOBUF_CONSTEXPR ProtobufCFileOptionsDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~ProtobufCFileOptionsDefaultTypeInternal() {}
  union {
    ProtobufCFileOptions _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 ProtobufCFileOptionsDefaultTypeInternal _ProtobufCFileOptions_default_instance_;

inline constexpr ProtobufCFieldOptions::Impl_::Impl_(
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        string_as_bytes_{false} {}

template <typename>
PROTOBUF_CONSTEXPR ProtobufCFieldOptions::ProtobufCFieldOptions(::_pbi::ConstantInitialized)
    : _impl_(::_pbi::ConstantInitialized()) {}
struct ProtobufCFieldOptionsDefaultTypeInternal {
  PROTOBUF_CONSTEXPR ProtobufCFieldOptionsDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~ProtobufCFieldOptionsDefaultTypeInternal() {}
  union {
    ProtobufCFieldOptions _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 ProtobufCFieldOptionsDefaultTypeInternal _ProtobufCFieldOptions_default_instance_;
static ::_pb::Metadata file_level_metadata_protobuf_2dc_2fprotobuf_2dc_2eproto[3];
static constexpr const ::_pb::EnumDescriptor**
    file_level_enum_descriptors_protobuf_2dc_2fprotobuf_2dc_2eproto = nullptr;
static constexpr const ::_pb::ServiceDescriptor**
    file_level_service_descriptors_protobuf_2dc_2fprotobuf_2dc_2eproto = nullptr;
const ::uint32_t TableStruct_protobuf_2dc_2fprotobuf_2dc_2eproto::offsets[] PROTOBUF_SECTION_VARIABLE(
    protodesc_cold) = {
    PROTOBUF_FIELD_OFFSET(::ProtobufCFileOptions, _impl_._has_bits_),
    PROTOBUF_FIELD_OFFSET(::ProtobufCFileOptions, _internal_metadata_),
    ~0u,  // no _extensions_
    ~0u,  // no _oneof_case_
    ~0u,  // no _weak_field_map_
    ~0u,  // no _inlined_string_donated_
    ~0u,  // no _split_
    ~0u,  // no sizeof(Split)
    PROTOBUF_FIELD_OFFSET(::ProtobufCFileOptions, _impl_.no_generate_),
    PROTOBUF_FIELD_OFFSET(::ProtobufCFileOptions, _impl_.gen_pack_helpers_),
    PROTOBUF_FIELD_OFFSET(::ProtobufCFileOptions, _impl_.gen_init_helpers_),
    PROTOBUF_FIELD_OFFSET(::ProtobufCFileOptions, _impl_.const_strings_),
    PROTOBUF_FIELD_OFFSET(::ProtobufCFileOptions, _impl_.use_oneof_field_name_),
    PROTOBUF_FIELD_OFFSET(::ProtobufCFileOptions, _impl_.c_package_),
    1,
    4,
    5,
    2,
    3,
    0,
    PROTOBUF_FIELD_OFFSET(::ProtobufCMessageOptions, _impl_._has_bits_),
    PROTOBUF_FIELD_OFFSET(::ProtobufCMessageOptions, _internal_metadata_),
    ~0u,  // no _extensions_
    ~0u,  // no _oneof_case_
    ~0u,  // no _weak_field_map_
    ~0u,  // no _inlined_string_donated_
    ~0u,  // no _split_
    ~0u,  // no sizeof(Split)
    PROTOBUF_FIELD_OFFSET(::ProtobufCMessageOptions, _impl_.gen_pack_helpers_),
    PROTOBUF_FIELD_OFFSET(::ProtobufCMessageOptions, _impl_.gen_init_helpers_),
    PROTOBUF_FIELD_OFFSET(::ProtobufCMessageOptions, _impl_.base_field_name_),
    1,
    2,
    0,
    PROTOBUF_FIELD_OFFSET(::ProtobufCFieldOptions, _impl_._has_bits_),
    PROTOBUF_FIELD_OFFSET(::ProtobufCFieldOptions, _internal_metadata_),
    ~0u,  // no _extensions_
    ~0u,  // no _oneof_case_
    ~0u,  // no _weak_field_map_
    ~0u,  // no _inlined_string_donated_
    ~0u,  // no _split_
    ~0u,  // no sizeof(Split)
    PROTOBUF_FIELD_OFFSET(::ProtobufCFieldOptions, _impl_.string_as_bytes_),
    0,
};

static const ::_pbi::MigrationSchema
    schemas[] PROTOBUF_SECTION_VARIABLE(protodesc_cold) = {
        {0, 14, -1, sizeof(::ProtobufCFileOptions)},
        {20, 31, -1, sizeof(::ProtobufCMessageOptions)},
        {34, 43, -1, sizeof(::ProtobufCFieldOptions)},
};

static const ::_pb::Message* const file_default_instances[] = {
    &::_ProtobufCFileOptions_default_instance_._instance,
    &::_ProtobufCMessageOptions_default_instance_._instance,
    &::_ProtobufCFieldOptions_default_instance_._instance,
};
const char descriptor_table_protodef_protobuf_2dc_2fprotobuf_2dc_2eproto[] PROTOBUF_SECTION_VARIABLE(protodesc_cold) = {
    "\n\033protobuf-c/protobuf-c.proto\032 google/pr"
    "otobuf/descriptor.proto\"\310\001\n\024ProtobufCFil"
    "eOptions\022\032\n\013no_generate\030\001 \001(\010:\005false\022\036\n\020"
    "gen_pack_helpers\030\002 \001(\010:\004true\022\036\n\020gen_init"
    "_helpers\030\003 \001(\010:\004true\022\034\n\rconst_strings\030\004 "
    "\001(\010:\005false\022#\n\024use_oneof_field_name\030\005 \001(\010"
    ":\005false\022\021\n\tc_package\030\006 \001(\t\"y\n\027ProtobufCM"
    "essageOptions\022\037\n\020gen_pack_helpers\030\001 \001(\010:"
    "\005false\022\036\n\020gen_init_helpers\030\002 \001(\010:\004true\022\035"
    "\n\017base_field_name\030\003 \001(\t:\004base\"7\n\025Protobu"
    "fCFieldOptions\022\036\n\017string_as_bytes\030\001 \001(\010:"
    "\005false:G\n\tpb_c_file\022\034.google.protobuf.Fi"
    "leOptions\030\373\007 \001(\0132\025.ProtobufCFileOptions:"
    "L\n\010pb_c_msg\022\037.google.protobuf.MessageOpt"
    "ions\030\373\007 \001(\0132\030.ProtobufCMessageOptions:J\n"
    "\npb_c_field\022\035.google.protobuf.FieldOptio"
    "ns\030\373\007 \001(\0132\026.ProtobufCFieldOptionsB\005\332\?\002\010\001"
};
static const ::_pbi::DescriptorTable* const descriptor_table_protobuf_2dc_2fprotobuf_2dc_2eproto_deps[1] =
    {
        &::descriptor_table_google_2fprotobuf_2fdescriptor_2eproto,
};
static ::absl::once_flag descriptor_table_protobuf_2dc_2fprotobuf_2dc_2eproto_once;
const ::_pbi::DescriptorTable descriptor_table_protobuf_2dc_2fprotobuf_2dc_2eproto = {
    false,
    false,
    680,
    descriptor_table_protodef_protobuf_2dc_2fprotobuf_2dc_2eproto,
    "protobuf-c/protobuf-c.proto",
    &descriptor_table_protobuf_2dc_2fprotobuf_2dc_2eproto_once,
    descriptor_table_protobuf_2dc_2fprotobuf_2dc_2eproto_deps,
    1,
    3,
    schemas,
    file_default_instances,
    TableStruct_protobuf_2dc_2fprotobuf_2dc_2eproto::offsets,
    file_level_metadata_protobuf_2dc_2fprotobuf_2dc_2eproto,
    file_level_enum_descriptors_protobuf_2dc_2fprotobuf_2dc_2eproto,
    file_level_service_descriptors_protobuf_2dc_2fprotobuf_2dc_2eproto,
};

// This function exists to be marked as weak.
// It can significantly speed up compilation by breaking up LLVM's SCC
// in the .pb.cc translation units. Large translation units see a
// reduction of more than 35% of walltime for optimized builds. Without
// the weak attribute all the messages in the file, including all the
// vtables and everything they use become part of the same SCC through
// a cycle like:
// GetMetadata -> descriptor table -> default instances ->
//   vtables -> GetMetadata
// By adding a weak function here we break the connection from the
// individual vtables back into the descriptor table.
PROTOBUF_ATTRIBUTE_WEAK const ::_pbi::DescriptorTable* descriptor_table_protobuf_2dc_2fprotobuf_2dc_2eproto_getter() {
  return &descriptor_table_protobuf_2dc_2fprotobuf_2dc_2eproto;
}
// Force running AddDescriptors() at dynamic initialization time.
PROTOBUF_ATTRIBUTE_INIT_PRIORITY2
static ::_pbi::AddDescriptorsRunner dynamic_init_dummy_protobuf_2dc_2fprotobuf_2dc_2eproto(&descriptor_table_protobuf_2dc_2fprotobuf_2dc_2eproto);
// ===================================================================

class ProtobufCFileOptions::_Internal {
 public:
  using HasBits = decltype(std::declval<ProtobufCFileOptions>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
    8 * PROTOBUF_FIELD_OFFSET(ProtobufCFileOptions, _impl_._has_bits_);
  static void set_has_no_generate(HasBits* has_bits) {
    (*has_bits)[0] |= 2u;
  }
  static void set_has_gen_pack_helpers(HasBits* has_bits) {
    (*has_bits)[0] |= 16u;
  }
  static void set_has_gen_init_helpers(HasBits* has_bits) {
    (*has_bits)[0] |= 32u;
  }
  static void set_has_const_strings(HasBits* has_bits) {
    (*has_bits)[0] |= 4u;
  }
  static void set_has_use_oneof_field_name(HasBits* has_bits) {
    (*has_bits)[0] |= 8u;
  }
  static void set_has_c_package(HasBits* has_bits) {
    (*has_bits)[0] |= 1u;
  }
};

ProtobufCFileOptions::ProtobufCFileOptions(::google::protobuf::Arena* arena)
    : ::google::protobuf::Message(arena) {
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:ProtobufCFileOptions)
}
inline PROTOBUF_NDEBUG_INLINE ProtobufCFileOptions::Impl_::Impl_(
    ::google::protobuf::internal::InternalVisibility visibility, ::google::protobuf::Arena* arena,
    const Impl_& from)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        c_package_(arena, from.c_package_) {}

ProtobufCFileOptions::ProtobufCFileOptions(
    ::google::protobuf::Arena* arena,
    const ProtobufCFileOptions& from)
    : ::google::protobuf::Message(arena) {
  ProtobufCFileOptions* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_);
  ::memcpy(reinterpret_cast<char *>(&_impl_) +
               offsetof(Impl_, no_generate_),
           reinterpret_cast<const char *>(&from._impl_) +
               offsetof(Impl_, no_generate_),
           offsetof(Impl_, gen_init_helpers_) -
               offsetof(Impl_, no_generate_) +
               sizeof(Impl_::gen_init_helpers_));

  // @@protoc_insertion_point(copy_constructor:ProtobufCFileOptions)
}
inline PROTOBUF_NDEBUG_INLINE ProtobufCFileOptions::Impl_::Impl_(
    ::google::protobuf::internal::InternalVisibility visibility,
    ::google::protobuf::Arena* arena)
      : _cached_size_{0},
        c_package_(arena),
        gen_pack_helpers_{true},
        gen_init_helpers_{true} {}

inline void ProtobufCFileOptions::SharedCtor(::_pb::Arena* arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char *>(&_impl_) +
               offsetof(Impl_, no_generate_),
           0,
           offsetof(Impl_, use_oneof_field_name_) -
               offsetof(Impl_, no_generate_) +
               sizeof(Impl_::use_oneof_field_name_));
}
ProtobufCFileOptions::~ProtobufCFileOptions() {
  // @@protoc_insertion_point(destructor:ProtobufCFileOptions)
  _internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  SharedDtor();
}
inline void ProtobufCFileOptions::SharedDtor() {
  ABSL_DCHECK(GetArena() == nullptr);
  _impl_.c_package_.Destroy();
  _impl_.~Impl_();
}

PROTOBUF_NOINLINE void ProtobufCFileOptions::Clear() {
// @@protoc_insertion_point(message_clear_start:ProtobufCFileOptions)
  PROTOBUF_TSAN_WRITE(&_impl_._tsan_detect_race);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (cached_has_bits & 0x00000001u) {
    _impl_.c_package_.ClearNonDefaultToEmpty();
  }
  ::memset(&_impl_.no_generate_, 0, static_cast<::size_t>(
      reinterpret_cast<char*>(&_impl_.use_oneof_field_name_) -
      reinterpret_cast<char*>(&_impl_.no_generate_)) + sizeof(_impl_.use_oneof_field_name_));
  if (cached_has_bits & 0x00000030u) {
    _impl_.gen_pack_helpers_ = true;
    _impl_.gen_init_helpers_ = true;
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

const char* ProtobufCFileOptions::_InternalParse(
    const char* ptr, ::_pbi::ParseContext* ctx) {
  ptr = ::_pbi::TcParser::ParseLoop(this, ptr, ctx, &_table_.header);
  return ptr;
}


PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<3, 6, 0, 38, 2> ProtobufCFileOptions::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(ProtobufCFileOptions, _impl_._has_bits_),
    0, // no _extensions_
    6, 56,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967232,  // skipmap
    offsetof(decltype(_table_), field_entries),
    6,  // num_field_entries
    0,  // num_aux_entries
    offsetof(decltype(_table_), field_names),  // no aux_entries
    &_ProtobufCFileOptions_default_instance_._instance,
    ::_pbi::TcParser::GenericFallback,  // fallback
  }, {{
    {::_pbi::TcParser::MiniParse, {}},
    // optional bool no_generate = 1 [default = false];
    {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(ProtobufCFileOptions, _impl_.no_generate_), 1>(),
     {8, 1, 0, PROTOBUF_FIELD_OFFSET(ProtobufCFileOptions, _impl_.no_generate_)}},
    // optional bool gen_pack_helpers = 2 [default = true];
    {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(ProtobufCFileOptions, _impl_.gen_pack_helpers_), 4>(),
     {16, 4, 0, PROTOBUF_FIELD_OFFSET(ProtobufCFileOptions, _impl_.gen_pack_helpers_)}},
    // optional bool gen_init_helpers = 3 [default = true];
    {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(ProtobufCFileOptions, _impl_.gen_init_helpers_), 5>(),
     {24, 5, 0, PROTOBUF_FIELD_OFFSET(ProtobufCFileOptions, _impl_.gen_init_helpers_)}},
    // optional bool const_strings = 4 [default = false];
    {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(ProtobufCFileOptions, _impl_.const_strings_), 2>(),
     {32, 2, 0, PROTOBUF_FIELD_OFFSET(ProtobufCFileOptions, _impl_.const_strings_)}},
    // optional bool use_oneof_field_name = 5 [default = false];
    {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(ProtobufCFileOptions, _impl_.use_oneof_field_name_), 3>(),
     {40, 3, 0, PROTOBUF_FIELD_OFFSET(ProtobufCFileOptions, _impl_.use_oneof_field_name_)}},
    // optional string c_package = 6;
    {::_pbi::TcParser::FastSS1,
     {50, 0, 0, PROTOBUF_FIELD_OFFSET(ProtobufCFileOptions, _impl_.c_package_)}},
    {::_pbi::TcParser::MiniParse, {}},
  }}, {{
    65535, 65535
  }}, {{
    // optional bool no_generate = 1 [default = false];
    {PROTOBUF_FIELD_OFFSET(ProtobufCFileOptions, _impl_.no_generate_), _Internal::kHasBitsOffset + 1, 0,
    (0 | ::_fl::kFcOptional | ::_fl::kBool)},
    // optional bool gen_pack_helpers = 2 [default = true];
    {PROTOBUF_FIELD_OFFSET(ProtobufCFileOptions, _impl_.gen_pack_helpers_), _Internal::kHasBitsOffset + 4, 0,
    (0 | ::_fl::kFcOptional | ::_fl::kBool)},
    // optional bool gen_init_helpers = 3 [default = true];
    {PROTOBUF_FIELD_OFFSET(ProtobufCFileOptions, _impl_.gen_init_helpers_), _Internal::kHasBitsOffset + 5, 0,
    (0 | ::_fl::kFcOptional | ::_fl::kBool)},
    // optional bool const_strings = 4 [default = false];
    {PROTOBUF_FIELD_OFFSET(ProtobufCFileOptions, _impl_.const_strings_), _Internal::kHasBitsOffset + 2, 0,
    (0 | ::_fl::kFcOptional | ::_fl::kBool)},
    // optional bool use_oneof_field_name = 5 [default = false];
    {PROTOBUF_FIELD_OFFSET(ProtobufCFileOptions, _impl_.use_oneof_field_name_), _Internal::kHasBitsOffset + 3, 0,
    (0 | ::_fl::kFcOptional | ::_fl::kBool)},
    // optional string c_package = 6;
    {PROTOBUF_FIELD_OFFSET(ProtobufCFileOptions, _impl_.c_package_), _Internal::kHasBitsOffset + 0, 0,
    (0 | ::_fl::kFcOptional | ::_fl::kRawString | ::_fl::kRepAString)},
  }},
  // no aux_entries
  {{
    "\24\0\0\0\0\0\11\0"
    "ProtobufCFileOptions"
    "c_package"
  }},
};

::uint8_t* ProtobufCFileOptions::_InternalSerialize(
    ::uint8_t* target,
    ::google::protobuf::io::EpsCopyOutputStream* stream) const {
  // @@protoc_insertion_point(serialize_to_array_start:ProtobufCFileOptions)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  // optional bool no_generate = 1 [default = false];
  if (cached_has_bits & 0x00000002u) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteBoolToArray(
        1, this->_internal_no_generate(), target);
  }

  // optional bool gen_pack_helpers = 2 [default = true];
  if (cached_has_bits & 0x00000010u) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteBoolToArray(
        2, this->_internal_gen_pack_helpers(), target);
  }

  // optional bool gen_init_helpers = 3 [default = true];
  if (cached_has_bits & 0x00000020u) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteBoolToArray(
        3, this->_internal_gen_init_helpers(), target);
  }

  // optional bool const_strings = 4 [default = false];
  if (cached_has_bits & 0x00000004u) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteBoolToArray(
        4, this->_internal_const_strings(), target);
  }

  // optional bool use_oneof_field_name = 5 [default = false];
  if (cached_has_bits & 0x00000008u) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteBoolToArray(
        5, this->_internal_use_oneof_field_name(), target);
  }

  // optional string c_package = 6;
  if (cached_has_bits & 0x00000001u) {
    const std::string& _s = this->_internal_c_package();
    ::google::protobuf::internal::WireFormat::VerifyUTF8StringNamedField(_s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormat::SERIALIZE,
                                "ProtobufCFileOptions.c_package");
    target = stream->WriteStringMaybeAliased(6, _s, target);
  }

  if (PROTOBUF_PREDICT_FALSE(_internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:ProtobufCFileOptions)
  return target;
}

::size_t ProtobufCFileOptions::ByteSizeLong() const {
// @@protoc_insertion_point(message_byte_size_start:ProtobufCFileOptions)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (cached_has_bits & 0x0000003fu) {
    // optional string c_package = 6;
    if (cached_has_bits & 0x00000001u) {
      total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                      this->_internal_c_package());
    }

    // optional bool no_generate = 1 [default = false];
    if (cached_has_bits & 0x00000002u) {
      total_size += 2;
    }

    // optional bool const_strings = 4 [default = false];
    if (cached_has_bits & 0x00000004u) {
      total_size += 2;
    }

    // optional bool use_oneof_field_name = 5 [default = false];
    if (cached_has_bits & 0x00000008u) {
      total_size += 2;
    }

    // optional bool gen_pack_helpers = 2 [default = true];
    if (cached_has_bits & 0x00000010u) {
      total_size += 2;
    }

    // optional bool gen_init_helpers = 3 [default = true];
    if (cached_has_bits & 0x00000020u) {
      total_size += 2;
    }

  }
  return MaybeComputeUnknownFieldsSize(total_size, &_impl_._cached_size_);
}

const ::google::protobuf::Message::ClassData ProtobufCFileOptions::_class_data_ = {
    ProtobufCFileOptions::MergeImpl,
    nullptr,  // OnDemandRegisterArenaDtor
};
const ::google::protobuf::Message::ClassData* ProtobufCFileOptions::GetClassData() const {
  return &_class_data_;
}

void ProtobufCFileOptions::MergeImpl(::google::protobuf::Message& to_msg, const ::google::protobuf::Message& from_msg) {
  auto* const _this = static_cast<ProtobufCFileOptions*>(&to_msg);
  auto& from = static_cast<const ProtobufCFileOptions&>(from_msg);
  // @@protoc_insertion_point(class_specific_merge_from_start:ProtobufCFileOptions)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void) cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (cached_has_bits & 0x0000003fu) {
    if (cached_has_bits & 0x00000001u) {
      _this->_internal_set_c_package(from._internal_c_package());
    }
    if (cached_has_bits & 0x00000002u) {
      _this->_impl_.no_generate_ = from._impl_.no_generate_;
    }
    if (cached_has_bits & 0x00000004u) {
      _this->_impl_.const_strings_ = from._impl_.const_strings_;
    }
    if (cached_has_bits & 0x00000008u) {
      _this->_impl_.use_oneof_field_name_ = from._impl_.use_oneof_field_name_;
    }
    if (cached_has_bits & 0x00000010u) {
      _this->_impl_.gen_pack_helpers_ = from._impl_.gen_pack_helpers_;
    }
    if (cached_has_bits & 0x00000020u) {
      _this->_impl_.gen_init_helpers_ = from._impl_.gen_init_helpers_;
    }
    _this->_impl_._has_bits_[0] |= cached_has_bits;
  }
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(from._internal_metadata_);
}

void ProtobufCFileOptions::CopyFrom(const ProtobufCFileOptions& from) {
// @@protoc_insertion_point(class_specific_copy_from_start:ProtobufCFileOptions)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

PROTOBUF_NOINLINE bool ProtobufCFileOptions::IsInitialized() const {
  return true;
}

::_pbi::CachedSize* ProtobufCFileOptions::AccessCachedSize() const {
  return &_impl_._cached_size_;
}
void ProtobufCFileOptions::InternalSwap(ProtobufCFileOptions* PROTOBUF_RESTRICT other) {
  using std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.c_package_, &other->_impl_.c_package_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(ProtobufCFileOptions, _impl_.gen_init_helpers_)
      + sizeof(ProtobufCFileOptions::_impl_.gen_init_helpers_)
      - PROTOBUF_FIELD_OFFSET(ProtobufCFileOptions, _impl_.no_generate_)>(
          reinterpret_cast<char*>(&_impl_.no_generate_),
          reinterpret_cast<char*>(&other->_impl_.no_generate_));
}

::google::protobuf::Metadata ProtobufCFileOptions::GetMetadata() const {
  return ::_pbi::AssignDescriptors(
      &descriptor_table_protobuf_2dc_2fprotobuf_2dc_2eproto_getter, &descriptor_table_protobuf_2dc_2fprotobuf_2dc_2eproto_once,
      file_level_metadata_protobuf_2dc_2fprotobuf_2dc_2eproto[0]);
}
// ===================================================================

class ProtobufCMessageOptions::_Internal {
 public:
  using HasBits = decltype(std::declval<ProtobufCMessageOptions>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
    8 * PROTOBUF_FIELD_OFFSET(ProtobufCMessageOptions, _impl_._has_bits_);
  static void set_has_gen_pack_helpers(HasBits* has_bits) {
    (*has_bits)[0] |= 2u;
  }
  static void set_has_gen_init_helpers(HasBits* has_bits) {
    (*has_bits)[0] |= 4u;
  }
  static void set_has_base_field_name(HasBits* has_bits) {
    (*has_bits)[0] |= 1u;
  }
};

/*static*/ const ::_pbi::LazyString ProtobufCMessageOptions::Impl_::_i_give_permission_to_break_this_code_default_base_field_name_{
    {{"base", 4}},
    {nullptr},
};
ProtobufCMessageOptions::ProtobufCMessageOptions(::google::protobuf::Arena* arena)
    : ::google::protobuf::Message(arena) {
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:ProtobufCMessageOptions)
}
inline PROTOBUF_NDEBUG_INLINE ProtobufCMessageOptions::Impl_::Impl_(
    ::google::protobuf::internal::InternalVisibility visibility, ::google::protobuf::Arena* arena,
    const Impl_& from)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        base_field_name_(arena, from.base_field_name_, _i_give_permission_to_break_this_code_default_base_field_name_) {}

ProtobufCMessageOptions::ProtobufCMessageOptions(
    ::google::protobuf::Arena* arena,
    const ProtobufCMessageOptions& from)
    : ::google::protobuf::Message(arena) {
  ProtobufCMessageOptions* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_);
  ::memcpy(reinterpret_cast<char *>(&_impl_) +
               offsetof(Impl_, gen_pack_helpers_),
           reinterpret_cast<const char *>(&from._impl_) +
               offsetof(Impl_, gen_pack_helpers_),
           offsetof(Impl_, gen_init_helpers_) -
               offsetof(Impl_, gen_pack_helpers_) +
               sizeof(Impl_::gen_init_helpers_));

  // @@protoc_insertion_point(copy_constructor:ProtobufCMessageOptions)
}
inline PROTOBUF_NDEBUG_INLINE ProtobufCMessageOptions::Impl_::Impl_(
    ::google::protobuf::internal::InternalVisibility visibility,
    ::google::protobuf::Arena* arena)
      : _cached_size_{0},
        base_field_name_(arena, Impl_::_i_give_permission_to_break_this_code_default_base_field_name_),
        gen_init_helpers_{true} {}

inline void ProtobufCMessageOptions::SharedCtor(::_pb::Arena* arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  _impl_.gen_pack_helpers_ = {};
}
ProtobufCMessageOptions::~ProtobufCMessageOptions() {
  // @@protoc_insertion_point(destructor:ProtobufCMessageOptions)
  _internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  SharedDtor();
}
inline void ProtobufCMessageOptions::SharedDtor() {
  ABSL_DCHECK(GetArena() == nullptr);
  _impl_.base_field_name_.Destroy();
  _impl_.~Impl_();
}

PROTOBUF_NOINLINE void ProtobufCMessageOptions::Clear() {
// @@protoc_insertion_point(message_clear_start:ProtobufCMessageOptions)
  PROTOBUF_TSAN_WRITE(&_impl_._tsan_detect_race);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (cached_has_bits & 0x00000001u) {
    _impl_.base_field_name_.ClearToDefault(::ProtobufCMessageOptions::Impl_::_i_give_permission_to_break_this_code_default_base_field_name_, GetArena());
  }
  if (cached_has_bits & 0x00000006u) {
    _impl_.gen_pack_helpers_ = false;
    _impl_.gen_init_helpers_ = true;
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

const char* ProtobufCMessageOptions::_InternalParse(
    const char* ptr, ::_pbi::ParseContext* ctx) {
  ptr = ::_pbi::TcParser::ParseLoop(this, ptr, ctx, &_table_.header);
  return ptr;
}


PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<2, 3, 0, 47, 2> ProtobufCMessageOptions::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(ProtobufCMessageOptions, _impl_._has_bits_),
    0, // no _extensions_
    3, 24,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967288,  // skipmap
    offsetof(decltype(_table_), field_entries),
    3,  // num_field_entries
    0,  // num_aux_entries
    offsetof(decltype(_table_), field_names),  // no aux_entries
    &_ProtobufCMessageOptions_default_instance_._instance,
    ::_pbi::TcParser::GenericFallback,  // fallback
  }, {{
    {::_pbi::TcParser::MiniParse, {}},
    // optional bool gen_pack_helpers = 1 [default = false];
    {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(ProtobufCMessageOptions, _impl_.gen_pack_helpers_), 1>(),
     {8, 1, 0, PROTOBUF_FIELD_OFFSET(ProtobufCMessageOptions, _impl_.gen_pack_helpers_)}},
    // optional bool gen_init_helpers = 2 [default = true];
    {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(ProtobufCMessageOptions, _impl_.gen_init_helpers_), 2>(),
     {16, 2, 0, PROTOBUF_FIELD_OFFSET(ProtobufCMessageOptions, _impl_.gen_init_helpers_)}},
    // optional string base_field_name = 3 [default = "base"];
    {::_pbi::TcParser::FastSS1,
     {26, 0, 0, PROTOBUF_FIELD_OFFSET(ProtobufCMessageOptions, _impl_.base_field_name_)}},
  }}, {{
    65535, 65535
  }}, {{
    // optional bool gen_pack_helpers = 1 [default = false];
    {PROTOBUF_FIELD_OFFSET(ProtobufCMessageOptions, _impl_.gen_pack_helpers_), _Internal::kHasBitsOffset + 1, 0,
    (0 | ::_fl::kFcOptional | ::_fl::kBool)},
    // optional bool gen_init_helpers = 2 [default = true];
    {PROTOBUF_FIELD_OFFSET(ProtobufCMessageOptions, _impl_.gen_init_helpers_), _Internal::kHasBitsOffset + 2, 0,
    (0 | ::_fl::kFcOptional | ::_fl::kBool)},
    // optional string base_field_name = 3 [default = "base"];
    {PROTOBUF_FIELD_OFFSET(ProtobufCMessageOptions, _impl_.base_field_name_), _Internal::kHasBitsOffset + 0, 0,
    (0 | ::_fl::kFcOptional | ::_fl::kRawString | ::_fl::kRepAString)},
  }},
  // no aux_entries
  {{
    "\27\0\0\17\0\0\0\0"
    "ProtobufCMessageOptions"
    "base_field_name"
  }},
};

::uint8_t* ProtobufCMessageOptions::_InternalSerialize(
    ::uint8_t* target,
    ::google::protobuf::io::EpsCopyOutputStream* stream) const {
  // @@protoc_insertion_point(serialize_to_array_start:ProtobufCMessageOptions)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  // optional bool gen_pack_helpers = 1 [default = false];
  if (cached_has_bits & 0x00000002u) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteBoolToArray(
        1, this->_internal_gen_pack_helpers(), target);
  }

  // optional bool gen_init_helpers = 2 [default = true];
  if (cached_has_bits & 0x00000004u) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteBoolToArray(
        2, this->_internal_gen_init_helpers(), target);
  }

  // optional string base_field_name = 3 [default = "base"];
  if (cached_has_bits & 0x00000001u) {
    const std::string& _s = this->_internal_base_field_name();
    ::google::protobuf::internal::WireFormat::VerifyUTF8StringNamedField(_s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormat::SERIALIZE,
                                "ProtobufCMessageOptions.base_field_name");
    target = stream->WriteStringMaybeAliased(3, _s, target);
  }

  if (PROTOBUF_PREDICT_FALSE(_internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:ProtobufCMessageOptions)
  return target;
}

::size_t ProtobufCMessageOptions::ByteSizeLong() const {
// @@protoc_insertion_point(message_byte_size_start:ProtobufCMessageOptions)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (cached_has_bits & 0x00000007u) {
    // optional string base_field_name = 3 [default = "base"];
    if (cached_has_bits & 0x00000001u) {
      total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                      this->_internal_base_field_name());
    }

    // optional bool gen_pack_helpers = 1 [default = false];
    if (cached_has_bits & 0x00000002u) {
      total_size += 2;
    }

    // optional bool gen_init_helpers = 2 [default = true];
    if (cached_has_bits & 0x00000004u) {
      total_size += 2;
    }

  }
  return MaybeComputeUnknownFieldsSize(total_size, &_impl_._cached_size_);
}

const ::google::protobuf::Message::ClassData ProtobufCMessageOptions::_class_data_ = {
    ProtobufCMessageOptions::MergeImpl,
    nullptr,  // OnDemandRegisterArenaDtor
};
const ::google::protobuf::Message::ClassData* ProtobufCMessageOptions::GetClassData() const {
  return &_class_data_;
}

void ProtobufCMessageOptions::MergeImpl(::google::protobuf::Message& to_msg, const ::google::protobuf::Message& from_msg) {
  auto* const _this = static_cast<ProtobufCMessageOptions*>(&to_msg);
  auto& from = static_cast<const ProtobufCMessageOptions&>(from_msg);
  // @@protoc_insertion_point(class_specific_merge_from_start:ProtobufCMessageOptions)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void) cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (cached_has_bits & 0x00000007u) {
    if (cached_has_bits & 0x00000001u) {
      _this->_internal_set_base_field_name(from._internal_base_field_name());
    }
    if (cached_has_bits & 0x00000002u) {
      _this->_impl_.gen_pack_helpers_ = from._impl_.gen_pack_helpers_;
    }
    if (cached_has_bits & 0x00000004u) {
      _this->_impl_.gen_init_helpers_ = from._impl_.gen_init_helpers_;
    }
    _this->_impl_._has_bits_[0] |= cached_has_bits;
  }
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(from._internal_metadata_);
}

void ProtobufCMessageOptions::CopyFrom(const ProtobufCMessageOptions& from) {
// @@protoc_insertion_point(class_specific_copy_from_start:ProtobufCMessageOptions)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

PROTOBUF_NOINLINE bool ProtobufCMessageOptions::IsInitialized() const {
  return true;
}

::_pbi::CachedSize* ProtobufCMessageOptions::AccessCachedSize() const {
  return &_impl_._cached_size_;
}
void ProtobufCMessageOptions::InternalSwap(ProtobufCMessageOptions* PROTOBUF_RESTRICT other) {
  using std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.base_field_name_, &other->_impl_.base_field_name_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(ProtobufCMessageOptions, _impl_.gen_init_helpers_)
      + sizeof(ProtobufCMessageOptions::_impl_.gen_init_helpers_)
      - PROTOBUF_FIELD_OFFSET(ProtobufCMessageOptions, _impl_.gen_pack_helpers_)>(
          reinterpret_cast<char*>(&_impl_.gen_pack_helpers_),
          reinterpret_cast<char*>(&other->_impl_.gen_pack_helpers_));
}

::google::protobuf::Metadata ProtobufCMessageOptions::GetMetadata() const {
  return ::_pbi::AssignDescriptors(
      &descriptor_table_protobuf_2dc_2fprotobuf_2dc_2eproto_getter, &descriptor_table_protobuf_2dc_2fprotobuf_2dc_2eproto_once,
      file_level_metadata_protobuf_2dc_2fprotobuf_2dc_2eproto[1]);
}
// ===================================================================

class ProtobufCFieldOptions::_Internal {
 public:
  using HasBits = decltype(std::declval<ProtobufCFieldOptions>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
    8 * PROTOBUF_FIELD_OFFSET(ProtobufCFieldOptions, _impl_._has_bits_);
  static void set_has_string_as_bytes(HasBits* has_bits) {
    (*has_bits)[0] |= 1u;
  }
};

ProtobufCFieldOptions::ProtobufCFieldOptions(::google::protobuf::Arena* arena)
    : ::google::protobuf::Message(arena) {
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:ProtobufCFieldOptions)
}
ProtobufCFieldOptions::ProtobufCFieldOptions(
    ::google::protobuf::Arena* arena, const ProtobufCFieldOptions& from)
    : ProtobufCFieldOptions(arena) {
  MergeFrom(from);
}
inline PROTOBUF_NDEBUG_INLINE ProtobufCFieldOptions::Impl_::Impl_(
    ::google::protobuf::internal::InternalVisibility visibility,
    ::google::protobuf::Arena* arena)
      : _cached_size_{0} {}

inline void ProtobufCFieldOptions::SharedCtor(::_pb::Arena* arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  _impl_.string_as_bytes_ = {};
}
ProtobufCFieldOptions::~ProtobufCFieldOptions() {
  // @@protoc_insertion_point(destructor:ProtobufCFieldOptions)
  _internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  SharedDtor();
}
inline void ProtobufCFieldOptions::SharedDtor() {
  ABSL_DCHECK(GetArena() == nullptr);
  _impl_.~Impl_();
}

PROTOBUF_NOINLINE void ProtobufCFieldOptions::Clear() {
// @@protoc_insertion_point(message_clear_start:ProtobufCFieldOptions)
  PROTOBUF_TSAN_WRITE(&_impl_._tsan_detect_race);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  _impl_.string_as_bytes_ = false;
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

const char* ProtobufCFieldOptions::_InternalParse(
    const char* ptr, ::_pbi::ParseContext* ctx) {
  ptr = ::_pbi::TcParser::ParseLoop(this, ptr, ctx, &_table_.header);
  return ptr;
}


PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<0, 1, 0, 0, 2> ProtobufCFieldOptions::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(ProtobufCFieldOptions, _impl_._has_bits_),
    0, // no _extensions_
    1, 0,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967294,  // skipmap
    offsetof(decltype(_table_), field_entries),
    1,  // num_field_entries
    0,  // num_aux_entries
    offsetof(decltype(_table_), field_names),  // no aux_entries
    &_ProtobufCFieldOptions_default_instance_._instance,
    ::_pbi::TcParser::GenericFallback,  // fallback
  }, {{
    // optional bool string_as_bytes = 1 [default = false];
    {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(ProtobufCFieldOptions, _impl_.string_as_bytes_), 0>(),
     {8, 0, 0, PROTOBUF_FIELD_OFFSET(ProtobufCFieldOptions, _impl_.string_as_bytes_)}},
  }}, {{
    65535, 65535
  }}, {{
    // optional bool string_as_bytes = 1 [default = false];
    {PROTOBUF_FIELD_OFFSET(ProtobufCFieldOptions, _impl_.string_as_bytes_), _Internal::kHasBitsOffset + 0, 0,
    (0 | ::_fl::kFcOptional | ::_fl::kBool)},
  }},
  // no aux_entries
  {{
  }},
};

::uint8_t* ProtobufCFieldOptions::_InternalSerialize(
    ::uint8_t* target,
    ::google::protobuf::io::EpsCopyOutputStream* stream) const {
  // @@protoc_insertion_point(serialize_to_array_start:ProtobufCFieldOptions)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  // optional bool string_as_bytes = 1 [default = false];
  if (cached_has_bits & 0x00000001u) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteBoolToArray(
        1, this->_internal_string_as_bytes(), target);
  }

  if (PROTOBUF_PREDICT_FALSE(_internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:ProtobufCFieldOptions)
  return target;
}

::size_t ProtobufCFieldOptions::ByteSizeLong() const {
// @@protoc_insertion_point(message_byte_size_start:ProtobufCFieldOptions)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  // optional bool string_as_bytes = 1 [default = false];
  cached_has_bits = _impl_._has_bits_[0];
  if (cached_has_bits & 0x00000001u) {
    total_size += 2;
  }

  return MaybeComputeUnknownFieldsSize(total_size, &_impl_._cached_size_);
}

const ::google::protobuf::Message::ClassData ProtobufCFieldOptions::_class_data_ = {
    ProtobufCFieldOptions::MergeImpl,
    nullptr,  // OnDemandRegisterArenaDtor
};
const ::google::protobuf::Message::ClassData* ProtobufCFieldOptions::GetClassData() const {
  return &_class_data_;
}

void ProtobufCFieldOptions::MergeImpl(::google::protobuf::Message& to_msg, const ::google::protobuf::Message& from_msg) {
  auto* const _this = static_cast<ProtobufCFieldOptions*>(&to_msg);
  auto& from = static_cast<const ProtobufCFieldOptions&>(from_msg);
  // @@protoc_insertion_point(class_specific_merge_from_start:ProtobufCFieldOptions)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void) cached_has_bits;

  if ((from._impl_._has_bits_[0] & 0x00000001u) != 0) {
    _this->_internal_set_string_as_bytes(from._internal_string_as_bytes());
  }
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(from._internal_metadata_);
}

void ProtobufCFieldOptions::CopyFrom(const ProtobufCFieldOptions& from) {
// @@protoc_insertion_point(class_specific_copy_from_start:ProtobufCFieldOptions)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}

PROTOBUF_NOINLINE bool ProtobufCFieldOptions::IsInitialized() const {
  return true;
}

::_pbi::CachedSize* ProtobufCFieldOptions::AccessCachedSize() const {
  return &_impl_._cached_size_;
}
void ProtobufCFieldOptions::InternalSwap(ProtobufCFieldOptions* PROTOBUF_RESTRICT other) {
  using std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
        swap(_impl_.string_as_bytes_, other->_impl_.string_as_bytes_);
}

::google::protobuf::Metadata ProtobufCFieldOptions::GetMetadata() const {
  return ::_pbi::AssignDescriptors(
      &descriptor_table_protobuf_2dc_2fprotobuf_2dc_2eproto_getter, &descriptor_table_protobuf_2dc_2fprotobuf_2dc_2eproto_once,
      file_level_metadata_protobuf_2dc_2fprotobuf_2dc_2eproto[2]);
}
PROTOBUF_ATTRIBUTE_INIT_PRIORITY2 ::google::protobuf::internal::ExtensionIdentifier< ::google::protobuf::FileOptions,
    ::google::protobuf::internal::MessageTypeTraits< ::ProtobufCFileOptions >, 11, false>
  pb_c_file(kPbCFileFieldNumber, ::ProtobufCFileOptions::default_instance(), nullptr);
PROTOBUF_ATTRIBUTE_INIT_PRIORITY2 ::google::protobuf::internal::ExtensionIdentifier< ::google::protobuf::MessageOptions,
    ::google::protobuf::internal::MessageTypeTraits< ::ProtobufCMessageOptions >, 11, false>
  pb_c_msg(kPbCMsgFieldNumber, ::ProtobufCMessageOptions::default_instance(), nullptr);
PROTOBUF_ATTRIBUTE_INIT_PRIORITY2 ::google::protobuf::internal::ExtensionIdentifier< ::google::protobuf::FieldOptions,
    ::google::protobuf::internal::MessageTypeTraits< ::ProtobufCFieldOptions >, 11, false>
  pb_c_field(kPbCFieldFieldNumber, ::ProtobufCFieldOptions::default_instance(), nullptr);
// @@protoc_insertion_point(namespace_scope)
namespace google {
namespace protobuf {
}  // namespace protobuf
}  // namespace google
// @@protoc_insertion_point(global_scope)
#include "google/protobuf/port_undef.inc"
